@@ -129,7 +129,7 @@ data CHSModule = CHSModule [CHSFrag]
 --  * `CHSHook' are binding hooks, which are being replaced by Haskell code by
 --   `GenBind.expandHooks' 
 --
---  * `CHSCPP' and `CHSC' are fragements of C code that are being removed when
+--  * `CHSCPP' and `CHSC' are fragments of C code that are being removed when
 --   generating the custom C header in `GenHeader.genHeader'
 --
 --  * `CHSCond' are strutured conditionals that are being generated by
@@ -393,7 +393,7 @@ dumpCHS fname mod pureHaskell  =
     contents version kind | hasCPP mod = showCHSModule mod pureHaskell
                           | otherwise = 
       "-- GENERATED by " ++ version ++ " " ++ kind ++ "\n\
-      \-- Edit the ORIGNAL .chs file instead!\n\n"
+      \-- Edit the ORIGINAL .chs file instead!\n\n"
       ++ showCHSModule mod pureHaskell
 
 -- to keep track of the current state of the line emission automaton
@@ -817,10 +817,10 @@ parseImport pos toks = do
   return $ CHSHook (CHSImport qual modid fName pos) : frags
 
 -- Qualified module names do not get lexed as a single token so we need to
--- reconstruct it from a sequence of identifer and dot tokens.
+-- reconstruct it from a sequence of identifier and dot tokens.
 --
 rebuildModuleId ide (CHSTokDot _ : CHSTokIdent _ ide' : toks) = 
-  let catIdent ide ide' = onlyPosIdent (posOf ide)  --FIXME: unpleasent hack
+  let catIdent ide ide' = onlyPosIdent (posOf ide)  --FIXME: unpleasant hack
                             (identToLexeme ide ++ '.' : identToLexeme ide')
    in rebuildModuleId (catIdent ide ide') toks
 rebuildModuleId ide                                     toks  = (ide, toks)
